@@ -20,14 +20,6 @@
 require_relative '../test_helper'
 
 class ProjectsControllerTest < Redmine::ControllerTest
-  fixtures :projects, :versions, :users, :email_addresses, :roles, :members,
-           :member_roles, :issues, :journals, :journal_details,
-           :trackers, :projects_trackers, :issue_statuses,
-           :enabled_modules, :enumerations, :boards, :messages,
-           :attachments, :custom_fields, :custom_values, :time_entries,
-           :wikis, :wiki_pages, :wiki_contents, :wiki_content_versions,
-           :roles, :queries, :issue_categories
-
   include Redmine::I18n
 
   def setup
